"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread2"));
var _react = _interopRequireWildcard(require("react"));
var _apolloLink = require("apollo-link");
var _apolloLinkContext = require("apollo-link-context");
var _loadScript = _interopRequireDefault(require("load-script"));
var _react2 = require("@emotion/react");
var _plugins = require("@webiny/plugins");
var _useI18N2 = require("@webiny/app-i18n/hooks/useI18N");
var _appSecurity = require("@webiny/app-security");
var _Progress = require("@webiny/ui/Progress");
var _Playground = require("./Playground.styles");
var _settings = require("./settings");
var _config = require("@webiny/app/config");
/**
 * Package load-script does not have types.
 */
// @ts-expect-error

var withHeaders = function withHeaders(link, headers) {
  return _apolloLink.ApolloLink.from([(0, _apolloLinkContext.setContext)(async function (_, req) {
    return {
      headers: (0, _objectSpread2.default)((0, _objectSpread2.default)({}, req.headers), headers)
    };
  }), link]);
};
var initScripts = function initScripts() {
  return new Promise(function (resolve) {
    // @ts-expect-error
    if (window.GraphQLPlayground) {
      return resolve();
    }
    return (0, _loadScript.default)("https://cdn.jsdelivr.net/npm/@apollographql/graphql-playground-react@1.7.32/build/static/js/middleware.js", resolve);
  });
};
var Playground = function Playground(_ref) {
  var createApolloClient = _ref.createApolloClient;
  var _useState = (0, _react.useState)(true),
    _useState2 = (0, _slicedToArray2.default)(_useState, 2),
    loading = _useState2[0],
    setLoading = _useState2[1];
  var _useI18N = (0, _useI18N2.useI18N)(),
    getCurrentLocale = _useI18N.getCurrentLocale;
  var _useSecurity = (0, _appSecurity.useSecurity)(),
    identity = _useSecurity.identity;
  var links = (0, _react.useRef)({});
  var locale = getCurrentLocale("content");
  var tabs = _plugins.plugins.byType("graphql-playground-tab").map(function (pl) {
    return pl.tab({
      locale: locale,
      identity: identity
    });
  }).filter(Boolean);
  var createApolloLink = (0, _react.useCallback)(function (_ref2) {
    var endpoint = _ref2.endpoint,
      headers = _ref2.headers;
    var current = links.current;
    // If the request endpoint is not know to us, return the first available
    var apiUrl = _config.config.getKey("API_URL", process.env.REACT_APP_API_URL);
    if (!endpoint.includes(apiUrl)) {
      return {
        link: withHeaders(Object.values(current)[0], headers)
      };
    }
    if (!current[endpoint]) {
      current[endpoint] = createApolloClient({
        uri: endpoint
      }).link;
    }
    return {
      link: withHeaders(current[endpoint], headers)
    };
  }, []);
  (0, _react.useEffect)(function () {
    initScripts().then(function () {
      setLoading(false);
    });
  }, []);
  (0, _react.useEffect)(function () {
    if (!loading) {
      // @ts-expect-error
      window.GraphQLPlayground.init(document.getElementById("graphql-playground"), {
        tabs: tabs,
        createApolloLink: createApolloLink,
        settings: _settings.settings
      });
    }
  }, [loading]);
  return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, loading ? /*#__PURE__*/_react.default.createElement(_Progress.CircularProgress, {
    label: "Loading playground..."
  }) : /*#__PURE__*/_react.default.createElement(_Playground.PlaygroundContainer, {
    id: "graphql-playground"
  }), /*#__PURE__*/_react.default.createElement(_react2.Global, {
    styles: _Playground.playgroundDialog
  }));
};
var _default = exports.default = Playground;

//# sourceMappingURL=Playground.js.map